@@ -1,17 +1,5 @@
-/*=========================================================================
-
-Program:   Visualization Toolkit
-Module:    vtkWin32OpenGLRenderWindow.cxx
-
-Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-All rights reserved.
-See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-This software is distributed WITHOUT ANY WARRANTY; without even
-the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkWin32OpenGLRenderWindow.h"
 
 #include "vtkCommand.h"
@@ -45,6 +33,7 @@ PURPOSE.  See the above copyright notice for more information.
 #define WM_MOUSEWHEEL 0x020A
 #endif // WM_MOUSEWHEEL
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkWin32OpenGLRenderWindow);
 
 const std::string vtkWin32OpenGLRenderWindow::DEFAULT_BASE_WINDOW_NAME =
@@ -154,8 +143,7 @@ void vtkWin32OpenGLRenderWindow::SetWindowName(const char* _arg)
   vtkWindow::SetWindowName(_arg);
   if (this->WindowId)
   {
-    std::wstring wname = vtksys::Encoding::ToWide(this->WindowName);
-    SetWindowTextW(this->WindowId, wname.c_str());
+    SetWindowText(this->WindowId, _arg);
   }
 }
 
@@ -839,6 +827,13 @@ LRESULT vtkWin32OpenGLRenderWindow::MessageProc(
         return 0;
       }
       break;
+    case WM_SETTEXT:
+    {
+      // Support for UTF-8, DefWindowProcW has to be called
+      // see https://stackoverflow.com/a/11515400
+      std::wstring wStr = vtksys::Encoding::ToWide((char*)(lParam));
+      return DefWindowProcW(hWnd, message, wParam, (LPARAM)wStr.c_str());
+    }
     case WM_PALETTECHANGED:
       /* realize palette if this is *not* the current window */
       if (this->ContextId && this->Palette && (HWND)wParam != hWnd)
@@ -1512,3 +1507,4 @@ bool vtkWin32OpenGLRenderWindow::DetectDPI()
   this->SetDPI(GetDeviceCaps(this->DeviceContext, LOGPIXELSY));
   return true;
 }
+VTK_ABI_NAMESPACE_END
